@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2016-07-20'; # DATE
-our $VERSION = '1.71'; # VERSION
+our $DATE = '2016-12-15'; # DATE
+our $VERSION = '1.72'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -349,12 +349,20 @@ sub hook_after_get_meta {
 
     if (risub($r->{meta})->can_dry_run) {
         $self->common_opts->{dry_run} = {
-            getopt  => 'dry-run',
-            summary => N__("Run in simulation mode (also via DRY_RUN=1)"),
+            getopt  => $self->default_dry_run ? 'dry-run!' : 'dry-run',
+            summary => $self->default_dry_run ?
+                N__("Disable simulation mode (also via DRY_RUN=0)") :
+                N__("Run in simulation mode (also via DRY_RUN=1)"),
             handler => sub {
                 my ($go, $val, $r) = @_;
-                $r->{dry_run} = 1;
-                $ENV{VERBOSE} = 1;
+                if ($val) {
+                    $log->debugf("[pericmd] Dry-run mode is activated");
+                    $r->{dry_run} = 1;
+                    #$ENV{VERBOSE} = 1;
+                } else {
+                    $log->debugf("[pericmd] Dry-run mode is deactivated");
+                    $r->{dry_run} = 0;
+                }
             },
         };
     }
@@ -783,7 +791,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.71 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2016-07-20.
+This document describes version 1.72 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2016-12-15.
 
 =head1 SYNOPSIS
 
